asr.gs
======

.. automodule:: asr.gs

   
   
   .. rubric:: Functions

   
   .. autofunction:: bz_soc
   .. autofunction:: evacdiff
   .. autofunction:: gaps
   .. autofunction:: get_1bz_k
   .. autofunction:: get_gap_info
   .. autofunction:: vacuumlevels
   .. autofunction:: webpanel
   
   

   
   
   

   
   
   